@@ -101,6 +101,11 @@ class CdistType(object):
         """Check whether a type is a singleton."""
         return os.path.isfile(os.path.join(self.absolute_path, "singleton"))
 
+    @property
+    def is_install(self):
+        """Check whether a type is used for installation (if not: for configuration)"""
+        return os.path.isfile(os.path.join(self.absolute_path, "install"))
+
     @property
     def explorers(self):
         """Return a list of available explorers"""
